<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Personalització del Conky - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Inicia </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Colors</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Per omissió</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Color0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Color1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Color2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Color3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Color4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Color5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Color6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Color7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Color8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Color9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="684"/>
        <source>Select Color</source>
        <translation>Trieu el color</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="790"/>
        <source>Permission Denied</source>
        <translation>Permís denegat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="791"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>No es pot escriure al fitxer %1
No teniu prou permisos.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Write Error</source>
        <translation>Error d&apos;escriptura</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Cannot write to file: %1</source>
        <translation>No es pot escriure al fitxer %1.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Backup Config File</source>
        <translation>Còpia de seguretat del fitxer de configuració </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Voleu conservar el fitxer original?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="897"/>
        <source>Backed Up Config File</source>
        <translation>S&apos;ha fet còpia de seguretat del fitxer de configuració</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="898"/>
        <source>The original configuration was backed up to %1</source>
        <translation>S&apos;ha fet una còpia de seguretat de la configuració original a %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Backup Failed</source>
        <translation>Ha fallat la còpia de seguretat.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Failed to create a backup file.</source>
        <translation>Ha fallat en crear la còpia de seguretat.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Restore Failed</source>
        <translation>Ha fallat la restauració.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <source>Failed to restore from backup file.</source>
        <translation>Ha fallat en restaurar la còpia de seguretat.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Backup file does not exist.</source>
        <translation>No hi ha fitxer de còpia de seguretat.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1328"/>
        <source>Position</source>
        <translation>Posició </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
        <source>Alignment</source>
        <translation>Alineació</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1340"/>
        <source>Top Left</source>
        <translation>Dalt a l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1341"/>
        <source>Top Right</source>
        <translation>Dalt a la dreta</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
        <source>Top Middle</source>
        <translation>Dalt al mig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1343"/>
        <source>Bottom Left</source>
        <translation>A baix a l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1344"/>
        <source>Bottom Right</source>
        <translation>A baix a la dreta</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1345"/>
        <source>Bottom Middle</source>
        <translation>A baix al mig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1346"/>
        <source>Middle Left</source>
        <translation>Al mig a l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
        <source>Middle Right</source>
        <translation>Al mig a la dreta</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
        <source>Middle Middle</source>
        <translation>Al mig al centre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
        <source>Horizontal Gap</source>
        <translation>Espaiat horitzontal</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Distància horitzontal de la finestra a la vora (en píxels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1366"/>
        <source>Vertical Gap</source>
        <translation>Espaiat vertical</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1367"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Distància vertical de la finestra a la vora (en píxels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1379"/>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1382"/>
        <source>Desktop 1</source>
        <translation>Escriptori 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1383"/>
        <source>All Desktops</source>
        <translation>Tots els escriptoris</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1395"/>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1407"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>L&apos;amplada ha de ser més grossa que la mida del contingut,
altrament aquest paràmetre no tindrà cap efecte.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1411"/>
        <source>Minimum Width</source>
        <translation>Amplada mínima</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1426"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>L&apos;alçada ha de ser més grossa que la mida del contingut,
altrament aquest paràmetre no tindrà cap efecte.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1428"/>
        <source>Minimum Height</source>
        <translation>Alçada mínima</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1442"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Incrementa l&apos;alçada de la finestra afegint línies buides al final del fitxer de configuració del Conky</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1443"/>
        <source>Height Padding</source>
        <translation>Farciment de l&apos;alçada</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1458"/>
        <source>Size</source>
        <translation>Mida </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1471"/>
        <source>Transparency Type</source>
        <translation>Tipus de transparència</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1476"/>
        <source>Opaque</source>
        <translation>Opaca</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1477"/>
        <source>Transparent</source>
        <translation>Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
        <source>Pseudo-Transparent</source>
        <translation>Pseudotransparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1479"/>
        <source>Semi-Transparent</source>
        <translation>Semitransparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Opacity (%)</source>
        <translation>Opacitat (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Opacitat de la finestra

0 = transparent del tot, 100 = opaca del tot</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Background Color</source>
        <translation>Color de fons</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1504"/>
        <source>Choose Color</source>
        <translation>Trieu un color</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1524"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Si definiu el tipus com a transparent, tota la finestra serà transparent (incloses les imatges). Feu servir pseudotransparent, si voleu que les imatges siguin opaques.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Si definiu el tipus com a pseudotransparent, la finestra serà transparent, però tindrà una ombra. L&apos;ombra es pot desactivar configurant el gestor de finestres.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1545"/>
        <source>Transparency</source>
        <translation>Transparència </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1556"/>
        <source>Date Format</source>
        <translation>Format de la data</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1559"/>
        <source>Day</source>
        <translation>Dia</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1561"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1572"/>
        <source>Long</source>
        <translation>Llarg</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1562"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1573"/>
        <source>Short</source>
        <translation>Curt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1563"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nom abreujat, p. ex.: dc </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1570"/>
        <source>Month</source>
        <translation>Mes</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1574"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nom abreujat, p. ex.: oct </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1593"/>
        <source>Time Format</source>
        <translation>Format de l&apos;hora</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1600"/>
        <source>Format</source>
        <translation>Format </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1605"/>
        <source>12 Hour</source>
        <translation>12 hores</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1606"/>
        <source>24 Hour</source>
        <translation>24 hores</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1621"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Data i hora</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1634"/>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1642"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1645"/>
        <source>WiFi Network</source>
        <translation>Xarxa de WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1648"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1651"/>
        <source>Wired LAN Network</source>
        <translation>Xarxa LAN amb cable</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1665"/>
        <source>Network</source>
        <translation>Xarxa</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1928"/>
        <source>Select Background Color</source>
        <translation>Trieu el color de fons</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>S&apos;executa</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Aturat</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Inici automàtic</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Personalitza</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Esborra </translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Inici</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Total: 0 monitors</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="595"/>
        <source>Total: %1 conkies</source>
        <translation>Total: %1 monitors</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Mostra: %1 de %2 monitors</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="547"/>
        <source>No Conky Selected</source>
        <translation>No s&apos;ha triat cap Conky.</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="549"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Trieu un monitor de la llista per veure&apos;n la previsualització.</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="568"/>
        <source>Preview image could not be loaded</source>
        <translation>No s&apos;ha pogut carregar la imatge de previsualització.</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>No preview image available</source>
        <translation>No hi ha imatge de previsualització disponible.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="57"/>
        <location filename="../src/mainwindow.cpp" line="829"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="249"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="247"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="254"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="269"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="267"/>
        <source>Close</source>
        <translation>Tanca </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>Loading Conky configurations...</source>
        <translation>Es carreguen les configuracions del Conky...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>Configure conky search paths</source>
        <translation>Configura els camins de cerca del Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="191"/>
        <source>Refresh</source>
        <translation>Refresca</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="193"/>
        <source>Refresh conky list</source>
        <translation>Refresca la llista de monitors</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="195"/>
        <source>Start All</source>
        <translation>Inicia&apos;ls tots</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="197"/>
        <source>Start all enabled conkies</source>
        <translation>Incia tots els monitors activats</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="199"/>
        <source>Stop All</source>
        <translation>Atura&apos;ls tots</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="201"/>
        <source>Stop all running conkies</source>
        <translation>Atura tots els monitors en execució</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="931"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Running</source>
        <translation>S&apos;executa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <location filename="../src/mainwindow.cpp" line="969"/>
        <source>Stopped</source>
        <translation>Aturat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="209"/>
        <source>Search conky by name...</source>
        <translation>Cerca un monitor pel nom...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="211"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Cerca monitors pel nom (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="256"/>
        <source>Display help</source>
        <translation>Mostra&apos;n l&apos;ajuda </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <location filename="../src/mainwindow.cpp" line="608"/>
        <source>Copy Conky</source>
        <translation>Copia el monitor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="478"/>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky Copied</source>
        <translation>Monitor copiat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>S&apos;ha copiat el monitor a la carpeta personal per a editar-lo:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Copy Failed</source>
        <translation>Ha fallat la còpia.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Ha fallat copiar el monitor a la carpeta personal.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="543"/>
        <source>Delete Conky</source>
        <translation>Esborra el monitor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="657"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>S&apos;ha copiat el monitor a la carpeta personal per personalitzar-lo:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Delete Successful</source>
        <translation>Eliminació correcta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>Previews</source>
        <translation>Previsualitzacions</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Generate preview images for conkies</source>
        <translation>Genera imatges de previsualització per a monitors</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <location filename="../src/mainwindow.cpp" line="929"/>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>All</source>
        <translation>Tots </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filtra els monitors per estat d&apos;execució o ubicació</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="428"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Enter a name for the copy:</source>
        <translation>Introduïu un nom per a la còpia:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="605"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Per tal d&apos;editar i desar un monitor, primer cal copiar-lo a ~/.conky on tingueu permís.
Introduïu un nom per a la còpia.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>Directory Exists</source>
        <translation>El directori ja hi és.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Ja hi ha un monitor amb el nom %1 a la carpeta personal.
El voleu sobreescriure?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>Edit Conky</source>
        <translation>Edita el monitor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Aquest fitxer de Conky és de només lectura i calen privilegis d&apos;administrador per editar-lo.
Voleu editar-lo amb privilegis superiors?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Segur que voleu esborrar el fitxer de Conky següent?
%1

Aquesta acció no es pot desfer.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Conky file deleted successfully.</source>
        <translation>Fitxer de Conky suprimit correctament</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Delete Failed</source>
        <translation>Ha fallat en esborrar.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Ha fallat esborrar el fitxer de Conky següent:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>Customize Conky</source>
        <translation>Personalitza el Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="667"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Aquest fitxer de Conky és de només lectura i calen privilegis d&apos;administrador per personalitzar-lo.
Voleu personalitzar-lo amb privilegis superiors?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Editor Error</source>
        <translation>Error de l&apos;editor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Cannot start editor for file: %1</source>
        <translation>No es pot iniciar l&apos;editor per al fitxer %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="828"/>
        <source>About MX Conky</source>
        <translation>Quant a l&apos;MX Conky </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="830"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="831"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Programa gràfic per configurar Conky a l&apos;MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>License</source>
        <translation>Llicència </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="836"/>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="837"/>
        <source>Cancel</source>
        <translation>Cancel·la </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="859"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="890"/>
        <source>MX Conky Help</source>
        <translation>Ajuda per a l&apos;MX Conky </translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Genera previsualització</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Genera imatges de previsualització per a</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Giny seleccionat</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Tots els ginys sense previsualització</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Tots els ginys (sobreescriu les imatges existents)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Ara no hi ha cap monitor seleccionat.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Imatges d&apos;alta qualitat (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Genera imatges de previsualització en format PNG en comptes de JPEG.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Sense elements</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>No hi ha cap giny de Conky que necessiti generar una previsualització.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="155"/>
        <source>Starting preview generation...</source>
        <translation>S&apos;inicia la generació de previsualitzacions...</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="159"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="198"/>
        <source>Generating preview for: %1</source>
        <translation>Es genera la previsualització per a %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="419"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Generació de previsualitzacions acomplerta! %1 previsualitzacions generades.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="423"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="426"/>
        <source>Preview Generation Complete</source>
        <translation>Generació de previsualitzacions acomplerta</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>S&apos;han generat amb èxit %1 imatges de previsualització.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Trieu el fitxer de configuració del gestor Conky.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Cal executar aquest programa com a usuari normal.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Trieu el directori per al Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>Paràmetres per a l&apos;MX Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Cerca de camins</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Inici automàtic</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Camins de cerca del Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Afegiu-hi un camí</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Elimina el camí</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Edita el camí</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Paràmetres de l&apos;arrencada automàtica</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Inicia el Conky en arrencar el sistema</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Retard per a l&apos;inici (segons): </translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
</TS>